==> reference3-1.0-sources.jar: one/xingyi/reference3/address/server/domain/AddressDebugInfo.java <==
package one.xingyi.reference3.address.server.domain;
//Made by one.xingyi.core.filemaker.CodeDomDebugFileMaker
//Defn one.xingyi.reference3.address.IAddressDefn
public class AddressDebugInfo {
/*
Deprecated: false
Original: one.xingyi.reference3.address.IAddressDefn
    IServer:    one.xingyi.reference3.address.server.domain.IAddress
    ServerImpl: one.xingyi.reference3.address.server.domain.Address
    Client:     one.xingyi.reference3.address.client.entitydefn.IAddressClientEntity
    ServComp:   one.xingyi.reference3.address.server.companion.AddressCompanion
    Lens:       Address
bookmarkAndUrl Optional.empty
Fields: 3
    Field: line1
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  line1/String
        Lens name  lens_Address_line1
        Readonly   false
        Javascript functionlens_Address_line1(){returnlens('line1');};
        Templated: false
        Deprecated false
    Field: line2
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  line2/String
        Lens name  lens_Address_line2
        Readonly   false
        Javascript functionlens_Address_line2(){returnlens('line2');};
        Templated: false
        Deprecated false
    Field: postcode
        PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String))
        Lens path  postcode/String
        Lens name  lens_Address_postcode
        Readonly   false
        Javascript functionlens_Address_postcode(){returnlens('postcode');};
        Templated: false
        Deprecated false
Get            Optional.empty
optionalGet    Optional.empty
Put            Optional.empty
Create         Optional.empty
CreateNoId     Optional.empty
Delete         Optional.empty
prototype:     Optional.empty
prototypeNoId: Optional.empty
Posts:         []
*/}

==> reference3-1.1-sources.jar: one/xingyi/reference3/address/server/domain/AddressDebugInfo.java <==
package one.xingyi.reference3.address.server.domain;
//Made by one.xingyi.core.filemaker.CodeDomDebugFileMaker
//Defn one.xingyi.reference3.address.IAddressDefn
public class AddressDebugInfo {
/*
Deprecated: false
Original: one.xingyi.reference3.address.IAddressDefn
    IServer:    one.xingyi.reference3.address.server.domain.IAddress
    ServerImpl: one.xingyi.reference3.address.server.domain.Address
    Client:     one.xingyi.reference3.address.client.entitydefn.IAddressClientEntity
    ServComp:   one.xingyi.reference3.address.server.companion.AddressCompanion
    Lens:       Address
bookmarkAndUrl Optional.empty
Fields: 3
    Field: line1
        StringPrimitiveType()
        Lens path  line1/String
        Lens name  lens_Address_line1
        Readonly   false
        Javascript functionlens_Address_line1(){returnlens('line1');};
        Templated: false
        Deprecated false
    Field: line2
        StringPrimitiveType()
        Lens path  line2/String
        Lens name  lens_Address_line2
        Readonly   false
        Javascript functionlens_Address_line2(){returnlens('line2');};
        Templated: false
        Deprecated false
    Field: postcode
        StringPrimitiveType()
        Lens path  postcode/String
        Lens name  lens_Address_postcode
        Readonly   false
        Javascript functionlens_Address_postcode(){returnlens('postcode');};
        Templated: false
        Deprecated false
Get            Optional.empty
optionalGet    Optional.empty
Put            Optional.empty
Create         Optional.empty
CreateNoId     Optional.empty
Delete         Optional.empty
prototype:     Optional.empty
prototypeNoId: Optional.empty
Posts:         []
*/}
